@@ -31,8 +31,9 @@ using Beagle.Daemon;
 using Beagle.Util;
 
 namespace Beagle.Filters {
+
 	public class FilterDeb : Beagle.Filters.FilterPackage {
-	
+
 		public FilterDeb ()
 		{
 		}
@@ -42,18 +43,18 @@ namespace Beagle.Filters {
 			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/x-deb"));
 		}
 		
-		protected override void PullPackageProperties ()
+		protected override bool PullPackageProperties ()
 		{
 			SafeProcess pc = new SafeProcess ();
 			pc.Arguments = new string [] { "dpkg-deb", "-I", FileInfo.FullName};
 			pc.RedirectStandardOutput = true;
+			pc.UseLangC = true;
 			
 			try {
 				pc.Start ();
 			} catch (SafeProcessException e) {
 				Log.Warn (e.Message);
-				Error ();
-				return;
+				return false;
 			}
 			
 			StreamReader pout = new StreamReader (pc.StandardOutput);
@@ -71,18 +72,15 @@ namespace Beagle.Filters {
 				switch (tokens[0].Trim ()) {
 					
 				case "Package":
-					PackageName = tokens[1];
+					PackageName = tokens [1];
 					break;
 					
 				case "Maintainer":
-					list = tokens [1].Split ('<');
-					PackagerName = list [0];
-					if (list.Length > 1)
-						PackagerEmail = list [1].Replace ('>', ' ');
+					Packager = tokens [1];
 					break;
 					
 				case "Version":
-					PackageVersion = tokens[1];
+					PackageVersion = tokens [1];
 					break;
 					
 				case "Section":
@@ -143,6 +141,7 @@ namespace Beagle.Filters {
 
 			pout.Close ();
 			pc.Close ();
+			return true;
 		}
 	}
 }
