@@ -41,12 +41,14 @@ namespace Beagle.Filters
 
 		protected string base_path;
 		protected string base_title;
+		protected string base_language;
 
 		protected Stack entries_stack = new Stack ();
 
 		protected class DocbookEntry {
 			public string Id = null;
 			public string Title = null;
+			public string Language = null;
 			public int Depth = -1;
 			public StringBuilder Content = new StringBuilder ();
 		}
@@ -56,19 +58,39 @@ namespace Beagle.Filters
 		public FilterDocbook ()
 		{
 			SnippetMode = false;
-			SetVersion (3);
+			SetVersion (4);
+			SetFileType ("documentation");
+		}
 
+		protected override void RegisterSupportedTypes ()
+		{
 			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/docbook+xml"));
 			AddSupportedFlavor (FilterFlavor.NewFromExtension (".docbook"));
 
-			// FIXME: Uri/Extension mapping?
-			AddSupportedFlavor (new FilterFlavor ("file:///usr/share/doc/*", ".xml", null, 0));
+			// Hack for detecting Docbook files in certain
+			// well-known locations.  These roughly map to the
+			// directories in crawl-rules/crawl-documentation
+			//
+			// xdgmime/shared-mime-info don't dive into XML files
+			// to see what they really are, so the mime type is
+			// just application/xml.  We know most of these are
+			// docbook.
+			AddSupportedFlavor (new FilterFlavor ("file:///usr/share/doc/*",              ".xml", null, 0));
+			AddSupportedFlavor (new FilterFlavor ("file:///usr/local/share/doc/*",        ".xml", null, 0));
+			AddSupportedFlavor (new FilterFlavor ("file:///opt/kde3/share/doc/*",         ".xml", null, 0));
+			AddSupportedFlavor (new FilterFlavor ("file:///opt/gnome/share/gnome/help/*", ".xml", null, 0));
+			AddSupportedFlavor (new FilterFlavor ("file:///usr/share/gnome/help/*",       ".xml", null, 0));
 		}
 
 		///////////////////////////////////////////////////
 
 		override protected void DoOpen (FileInfo info)
 		{
+			if (info.Name == "legal.xml") {
+				Error ();
+				return;
+			}
+
 			base_path = info.FullName;		
 			reader = new XmlTextReader (Stream);
 			reader.XmlResolver = null;
@@ -86,12 +108,23 @@ namespace Beagle.Filters
 					if (reader.Name.StartsWith ("sect") || reader.Name.StartsWith ("chapter")) {
 						string id = reader.GetAttribute ("id");
 
-						if (id != null && id != "") {
+						if (id != null && id != String.Empty) {
 							DocbookEntry entry = new DocbookEntry ();
 							entry.Id = id;
 							entry.Depth = reader.Depth;
+
+							string language = reader.GetAttribute ("lang");
+							
+							if (language != null && language != String.Empty)
+								entry.Language = language;
+
 							entries_stack.Push (entry);
 						}
+					} else if (reader.Name == "article" || reader.Name == "book") {
+						string language = reader.GetAttribute ("lang");
+
+						if (language != null && language != String.Empty)
+							base_language = language;
 					} else if (reader.Name == "title") {
 						reader.Read (); // Go to the text node
 
@@ -117,7 +150,8 @@ namespace Beagle.Filters
 					break;
 					
 				case XmlNodeType.EndElement:
-					if (entries_stack.Count > 0 && ((DocbookEntry) entries_stack.Peek ()).Depth == reader.Depth) {
+					if (entries_stack.Count > 0 &&
+					    ((DocbookEntry) entries_stack.Peek ()).Depth == reader.Depth) {
 						DocbookEntry entry, parent_entry = null;
 
 						entry = (DocbookEntry) entries_stack.Pop ();
@@ -127,40 +161,53 @@ namespace Beagle.Filters
 						
 						Indexable indexable = new Indexable (UriFu.PathToFileUri (String.Format ("{0}#{1}", base_path, entry.Id)));
 						indexable.HitType = "DocbookEntry";
-						indexable.MimeType = "text/plain";
+						indexable.MimeType = "text/x-docbook-entry";
+						indexable.Filtering = IndexableFiltering.AlreadyFiltered;
+
 						indexable.AddProperty (Property.NewUnsearched ("fixme:id", entry.Id));
-						
-						if (entry.Title != null)
-							indexable.AddProperty (Property.New ("dc:title", entry.Title));
-						
+						indexable.AddProperty (Property.New ("dc:title", entry.Title));
+
 						// Add the docbook book title
-						if (base_title != null)
-							indexable.AddProperty (Property.NewUnsearched ("fixme:base_title", base_title));
+						indexable.AddProperty (Property.NewUnsearched ("fixme:base_title", base_title));
+
+						// Add the child language (or docbook language if none is specified)
+						if (entry.Language != null)
+							indexable.AddProperty (Property.NewUnsearched ("fixme:language", entry.Language));
+						else if (base_language != null)
+							indexable.AddProperty (Property.NewUnsearched ("fixme:language", base_language));
 						
 						// Add any parent (as in docbook parent entry, not beagle) data if we have it
 						if (parent_entry != null) {
 							indexable.AddProperty (Property.NewUnsearched ("fixme:parent_id", parent_entry.Id));
-
-							if (parent_entry.Title != null)
-								indexable.AddProperty (Property.NewUnsearched ("fixme:parent_title", parent_entry.Title));
+							indexable.AddProperty (Property.NewUnsearched ("fixme:parent_title", parent_entry.Title));
 						}
 
 
 						StringReader content_reader = new StringReader (entry.Content.ToString ());
 						indexable.SetTextReader (content_reader);
-						
-						AddChildIndexable (indexable);
+						indexable.SetChildOf (this.Indexable);
+
+						AddIndexable (indexable);
 					}
 					break;
 				}
 			}
 
+			// Add the common properties to the top-level
+			// file item such as Title, Language etc.
+
+			AddProperty (Property.New ("dc:title", base_title));
+			AddProperty (Property.NewUnsearched ("fixme:language", base_language));
+
 			watch.Stop ();
 			
 			// If we've successfully crawled the file but haven't 
 			// found any indexables, we shouldn't consider it
-			// successfull at all.
-			if (ChildIndexables.Count == 0) {
+			// successfull at all (unless we have a title, which
+			// means that it's actually a docbook file, just without
+			// sections.
+			if (! HasGeneratedIndexable && base_title == null) {
+				Log.Error ("Probably not a docbook. Ignoring {0}!", base_path);
 				Error ();
 				return;
 			}
