@@ -40,8 +40,16 @@ namespace Beagle.Filters {
 		static bool Debug = false;
 
 		public FilterTotem ()
-		{
+		{			
+			// 1: Priority update after FilterVideo was added
+			SetVersion (1);
+
 			PreLoad = false;
+			SetFileType ("video");
+		}
+
+		internal static int Priority {
+			get { return 1 + FilterMPlayerVideo.Priority; }
 		}
 
 		protected override void RegisterSupportedTypes ()
@@ -52,6 +60,7 @@ namespace Beagle.Filters {
 			pc.Arguments = new string [] { "totem-video-indexer", "--mimetype" };
 			pc.RedirectStandardOutput = true;
 			pc.RedirectStandardError = true;
+			pc.UseLangC = true;
 
 			try {
 				pc.Start ();
@@ -66,7 +75,10 @@ namespace Beagle.Filters {
 			string str;
 
 			while ((str = pout.ReadLine ()) != null) {
-				AddSupportedFlavor (FilterFlavor.NewFromMimeType (str));
+				FilterFlavor flavor = FilterFlavor.NewFromMimeType (str);
+				flavor.Priority = Priority;
+
+				AddSupportedFlavor (flavor);
 
 				if (Debug)
 					Log.Debug ("Added {0} as a supported mime type for Totem video filter", str);
@@ -78,8 +90,14 @@ namespace Beagle.Filters {
 
 		protected override void DoPullProperties ()
 		{
+			if (FileInfo == null) {
+				Log.Error ("FilterTotem: Unable to extract properties for non-file data");
+				Error ();
+				return;
+			}
+
 			SafeProcess pc = new SafeProcess ();
-			pc.Arguments = new string [] { "totem-video-indexer", UriFu.UriToEscapedString (this.Uri) };
+			pc.Arguments = new string [] { "totem-video-indexer", FileInfo.FullName };
 			pc.RedirectStandardOutput = true;
 			pc.RedirectStandardError = true;
 
