@@ -1,7 +1,7 @@
 //
 // ImLogWindow.cs
 //
-// Lukas Lipka <lukas@pmad.net>
+// Lukas Lipka <lukaslipka@gmail.com>
 // Raphael  Slinckx <rslinckx@gmail.com>
 //
 // Copyright (C) 2005 Novell, Inc.
@@ -87,23 +87,41 @@ namespace ImLogViewer {
 		
 		private void SetWindowTitle (string speaker)
 		{
-			if (speaker == null || speaker.Length == 0)
+			if (String.IsNullOrEmpty (speaker))
 				return;
 
 			// Find the buddy
 			ImBuddy buddy = null;
+			ImBuddyListReader reader = null;
 
-			if (client == ImClient.Gaim)
-				buddy = new GaimBuddyListReader ().Search (speaker);
-			else if (client == ImClient.Kopete)
-				buddy = new KopeteBuddyListReader ().Search (speaker);
+			if (client == ImClient.Pidgin) {
+				reader = new PidginBuddyListReader ();
+				buddy = reader.Search (speaker);
+			} else if (client == ImClient.Kopete) {
+				reader = new KopeteBuddyListReader ();
+				buddy = reader.Search (speaker);
+			} else if (client == ImClient.Konversation) {
+				int pos = speaker.IndexOf ('_');
+
+				// speaker of the form irc.gimp.net_#mono-dev
+				if (pos == -1)
+					imviewer.Title = String.Format (Catalog.GetString ("Conversations in {0}"), speaker);
+				else	
+					imviewer.Title = String.Format (
+						Catalog.GetString ("Conversations in {0} ({1})"),
+						speaker.Substring (pos + 1),
+						speaker.Substring (0, pos));
+
+				speaking_to = speaker;
+				return;
+			}
 			
 			if (speaker.EndsWith (".chat")) {
 				imviewer.Title = String.Format (Catalog.GetString ("Conversations in {0}"), speaker.Replace (".chat", String.Empty));
 			} else {
 				string nick = speaker;
 
-				if (buddy != null && buddy.Alias.Length > 0)
+				if (buddy != null && ! String.IsNullOrEmpty (buddy.Alias))
 					nick = buddy.Alias;
 
 				imviewer.Title = String.Format (Catalog.GetString ("Conversations with {0}"), nick);
@@ -118,7 +136,8 @@ namespace ImLogViewer {
 			
 			Glade.XML gxml = new Glade.XML (null, "ImLogViewer.glade", "imviewer", null);
 			gxml.Autoconnect (this);
-			imviewer.Icon = Beagle.Images.GetPixbuf ("system-search.png");
+
+			imviewer.Icon = IconTheme.Default.LoadIcon ("system-search", 16, IconLookupFlags.NoSvg);
 
 			conversation.PixelsAboveLines = 3;
 			conversation.LeftMargin = 4;
@@ -169,10 +188,12 @@ namespace ImLogViewer {
 				ImLog log = null;
 				StreamReader reader = new StreamReader (file);
 				
-				if (client == ImClient.Gaim)
-					log = new GaimLog (new FileInfo (file), reader);
+				if (client == ImClient.Pidgin)
+					log = new PidginLog (new FileInfo (file), reader);
 				else if (client == ImClient.Kopete)
 					log = new KopeteLog (new FileInfo (file), reader);
+				else if (client == ImClient.Konversation)
+					log = new KonversationLog (new FileInfo (file));
 
 				reader.Close ();
 
@@ -183,7 +204,7 @@ namespace ImLogViewer {
 				
 				if (speaking_to == null)
 					SetWindowTitle (log.SpeakingTo);
-					timeline.Add (log, log.StartTime);
+				timeline.Add (log, log.StartTime);
 			}
 
 			index_thread_notify.WakeupMain ();
@@ -227,10 +248,11 @@ namespace ImLogViewer {
 			}
 
 			if (preview == null)
-				return ((ImLog.Utterance) log.Utterances [0]).Text;
+				preview = ((ImLog.Utterance) log.Utterances [0]).Text;
 
 			if (preview.Length > 50)
-				return preview.Substring (0, 50) + "...";
+				preview = preview.Substring (0, 50) + "...";
+
 			return preview;
 		}
 
